@@ -1,3 +1,4 @@
+import importlib.metadata
 import os
 import tempfile
 from typing import Dict, Final
@@ -19,7 +20,7 @@ from panther_analysis_tool.schemas import (
 
 PACKAGE_NAME: Final = "panther_analysis_tool"
 
-VERSION_STRING: Final = "0.56.0"
+VERSION_STRING: Final = importlib.metadata.version(PACKAGE_NAME)
 
 CONFIG_FILE = ".panther_settings.yml"
 DATA_MODEL_LOCATION = "./data_models"
