@@ -1,22 +1,3 @@
-"""
-Panther Analysis Tool is a command line interface for writing,
-testing, and packaging policies/rules.
-Copyright (C) 2020 Panther Labs Inc
-
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
-
-You should have received a copy of the GNU Affero General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-
 import json
 import pkgutil
 from typing import Any, Dict
@@ -136,6 +117,7 @@ POLICY_SCHEMA = Schema(
         Optional("DisplayName"): And(str, NAME_ID_VALIDATION_REGEX),
         Optional("OnlyUseBaseRiskScore"): bool,
         Optional("OutputIds"): [str],
+        Optional("CreatedBy"): str,
         Optional("Reference"): str,
         Optional("Runbook"): str,
         Optional("Suppressions"): [str],
@@ -170,6 +152,7 @@ RULE_SCHEMA = Schema(
         Optional("DisplayName"): And(str, NAME_ID_VALIDATION_REGEX),
         Optional("OnlyUseBaseRiskScore"): bool,
         Optional("OutputIds"): [str],
+        Optional("CreatedBy"): str,
         Optional("Reference"): str,
         Optional("Runbook"): str,
         Optional("SummaryAttributes"): [str],
@@ -236,6 +219,7 @@ CORRELATION_RULE_SCHEMA = Schema(
         Optional("DisplayName"): And(str, NAME_ID_VALIDATION_REGEX),
         Optional("OnlyUseBaseRiskScore"): bool,
         Optional("OutputIds"): [str],
+        Optional("CreatedBy"): str,
         Optional("Reference"): str,
         Optional("Runbook"): str,
         Optional("SummaryAttributes"): [str],
@@ -300,11 +284,13 @@ LOOKUP_TABLE_SCHEMA = Schema(
         Or("Filename", "Refresh"): Or(
             str,
             {
-                "RoleARN": str,
                 "ObjectPath": str,
                 Optional("PeriodMinutes"): int,
                 Optional("AlarmPeriodMinutes"): int,
+                Optional("RoleARN"): str,
                 Optional("ObjectKMSKey"): str,
+                Optional("GCSCredentials"): str,
+                Optional("StorageProvider"): str,
             },
         ),
         "Schema": str,
